package com.example.backend;

import java.util.Objects;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.CommandLineRunner;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;

import com.example.backend.categories.model.CategorieEntity;
import com.example.backend.categories.service.CategorieService;
import com.example.backend.movies.model.MovieEntity;
import com.example.backend.movies.service.MovieService;

// create lab 2

@SpringBootApplication
public class BackendApplication implements CommandLineRunner {

	private final Logger _logger = LoggerFactory.getLogger(BackendApplication.class);

	private final CategorieService categorieService;
	private final MovieService movieService;

	public BackendApplication(CategorieService categorieService, MovieService movieService) {
		this.categorieService = categorieService;
		this.movieService = movieService;

	}

	public static void main(String[] args) {
		SpringApplication.run(BackendApplication.class, args);
	}

	@Override
	public void run(String... args) throws Exception {

		if (args.length > 0 && Objects.equals("--populate", args[0])) {

			_logger.info("Create default categories values");

			final var categorie1 = categorieService.create(new CategorieEntity(1,
					"Драма", "placeholder"));
			final var categorie2 = categorieService.create(new CategorieEntity(2,
					"Комедия", "placeholder"));
			final var categorie3 = categorieService.create(new CategorieEntity(4,
					"Хоррор", "placeholder"));

			_logger.info("Create default movies values");

			movieService.create(new MovieEntity(1, categorie3, "Астрал", "1", "1", "1"));
			movieService.create(new MovieEntity(1, categorie1, "Хатико", "2", "2", "2"));
			movieService.create(new MovieEntity(1, categorie2, "Бабушка легкого ", "3", "3", "3"));
			movieService.create(new MovieEntity(1, categorie3, "Пиковая дама", "4", "4",
					"4"));
			movieService.create(new MovieEntity(1, categorie3, "Баба-Яга", "5", "5", "5"));

		}
	}

}
